/**
 * The class of file paths in the tool.
 * @class
 */
export class FilePath {
    /**
     * Defining the initial values of the class instance.
     * @param {string} filePath - An absolute or relative to workspace path, if not, the `relativeTo` parameter must have a value.
     * @param {string} [relativeTo] - The path relative to the location of the `filePath` parameter if wasn't relative to the workspace.
     * @throws {Error} If `filePath` is not absolute or relative to workspace path.
     */
    constructor(filePath: string, relativeTo?: string);
    /**
     * File name without extension.
     * @type {string}
     * @example
     * const fp = new FilePath("example.test.js");
     * // fp.name = "example"
     */
    name: string;
    /**
     * File's parent folder/directory name.
     * @type {string}
     * @example
     * const fp = new FilePath("main/example.js");
     * // fp.folder = "main"
     */
    folder: string;
    /**
     * File extension after the first dot.
     * @type {string}
     * @example
     * const fp = new FilePath("example.test.js");
     * // fp.extension = "test.js"
     */
    extension: string;
    /**
     * File's absolute path before the parent folder/directory.
     * @type {string}
     * @example
     * const fp = new FilePath("C:/users/someone/main/example.js");
     * // fp.root = "C:/users/someone"
     */
    root: string;
    /**
     * @returns {string} - File name with extension
     * @public
     */
    public get fullName(): string;
    /**
     * @returns {string} - Absolute file path
     * @public
     */
    public get fullPath(): string;
}
