import type { FilterOptions } from "../options";
import type { FilePath } from "../class/filePath";

/**
 * Search for the first stored FilePath matching the given filter options.
 * @param {FilterOptions} options - Path's search filter options.
 * @returns {FilePath | void} - The FilePath if found, otherwise undefined.
 * @example <caption>will return the first file called "example"</caption>
 * const filePath = findPath({ name: "example" });
 * const { ... } = require(filePath.fullPath);
 */
export declare function findPath(options: FilterOptions): FilePath | void;
/**
 * Find all stored paths with filtering.
 * @param {FilterOptions} [options] - If options is null, all the paths will be returned.
 * @returns {FilePath[]} - If no paths found, an empty array will be returned.
 * @example <caption>will return all stored js files</caption>
 * findPaths({ extension: "js" });
 * @example <caption>will return all stored js and json files</caption>
 * findPaths({ extension: /^js(on)?$/ });
 */
export declare function findPaths(options?: FilterOptions): FilePath[];
