import type { SearchOptions } from "../options";

/**
 * Get all folder names in the root directory of the workspace.
 * The function will automatically ignore all directories with `.` (dot) or `_` (underscore).
 * @returns {Promise<string[]>} - An array of the folder names.
 * @example <caption>If the top level folders are "src", "dist", "node_modules" and ".git", then it will return ["src", "dist"]</caption>
 * const folderNames = readWorkspaceFolderNames();
 */
export declare function readWorkspaceFolderNames(): Promise<string[]>;
/**
 * Get all paths inside a folder path.
 * @param {string} folderPath - The path of the folder to read.
 * @param {SearchOptions} options - Whether to read subfolders or not.
 * @returns {Promise<string[]>} An array of paths.
 * @example
 * const paths = readFolderPaths(["src"]);
 * @example
 * const paths = readFolderPaths(["src"], { deepSearch = true });
 */
export declare function readFolderPaths(folderPath: string, options: SearchOptions): Promise<string[]>;
