import type { SearchOptions } from "../options";

/**
 * Check if a file path saved.
 * @param {string} path - The path string to check for.
 * @returns {boolean} True if saved, false otherwise.
 * @example
 * if (storedPath(".../example.js")) { ... }
 */
export declare function storedPath(path: string): boolean;
/**
 * Add file paths to the saved ones if not saved already.
 * @param {string[]} paths - Paths to add.
 * @returns {void}
 * @example
 * storePaths(["example1.js", "src/example2.js"]);
 */
export declare function storePaths(paths: string[]): void;
/**
 * Save all file paths in specific folder.
 * @param {string[]} [folderPaths] - Folder path to search in.
 * @param {SearchOptions} [options] - Whether to search subfolders. @defaultValue { deepSearch: true }
 * @returns {Promise<void>}
 * @example
 * storeFolderPaths();
 * @example
 * storeFolderPaths(["src"]);
 * @example
 * storeFolderPaths(["src", "src/main"], { deepSearch: false });
 */
export declare function storeFolderPaths(folderPaths?: string[], options?: SearchOptions): Promise<void>;
